| Title: | MSigDB Data Frame |
|---|---|
| Description: | Provides the Molecular Signatures Database (MSigDB) gene sets (Subramanian et al. 2005 <doi:10.1073/pnas.0506580102>, Liberzon et al. 2015 <doi:10.1016/j.cels.2015.12.004>, Castanza et al. 2023 <doi:10.1038/s41592-023-02014-7>) in an R data frame. Serves as the data source for 'msigdbr' <doi:10.32614/CRAN.package.msigdbr> (split into a separate package due to CRAN size restrictions). |
| Authors: | Igor Dolgalev [aut, cre] (ORCID: <https://orcid.org/0000-0003-4451-126X>) |
| Maintainer: | Igor Dolgalev <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 26.1.0 |
| Built: | 2026-05-10 08:55:59 UTC |
| Source: | https://github.com/igordot/msigdbrdata |
Retrieve a data frame of MSigDB gene sets and their member genes.
Starting with release 2022.1, MSigDB was split into human and mouse resources, each one provided in the approved gene symbols of its respective species.
The MSigDB versioning convention is in the format Year.Release.Species.
The species referenced in this function is the one specified in the release version.
msigdbrdata(target_species = c("HS", "MM"))msigdbrdata(target_species = c("HS", "MM"))
target_species |
Species abbreviation for human or mouse databases ( |
A data frame of gene sets with one gene per row.
Subramanian A, Tamayo P, Mootha VK, Mukherjee S, Ebert BL, Gillette MA, Paulovich A, Pomeroy SL, Golub TR, Lander ES, Mesirov JP. Gene set enrichment analysis: a knowledge-based approach for interpreting genome-wide expression profiles. Proc Natl Acad Sci. 2005 Oct 25;102(43):15545-50. doi:10.1073/pnas.0506580102
Liberzon A, Birger C, Thorvaldsdóttir H, Ghandi M, Mesirov JP, Tamayo P. The Molecular Signatures Database (MSigDB) hallmark gene set collection. Cell Syst. 2015 Dec 23;1(6):417-425. doi:10.1016/j.cels.2015.12.004
Castanza AS, Recla JM, Eby D, Thorvaldsdóttir H, Bult CJ, Mesirov JP. Extending support for mouse data in the Molecular Signatures Database (MSigDB). Nat Methods. 2023 Nov;20(11):1619-1620. doi:10.1038/s41592-023-02014-7